pub struct Async { /* private fields */ }Expand description
Async drain
Async will send all the logging records to a wrapped drain running in another thread.
Note: Dropping Async waits for it’s worker-thread to finish (thus handle all previous
requests). If you can’t tolerate the delay, make sure you drop Async drain instance eg. in
another thread.
Implementations